==> vtk6-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkSLACReader.java <==
// java wrapper for vtkSLACReader object
//

package vtk;
import vtk.*;

public class vtkSLACReader extends vtkMultiBlockDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetMeshFileName_2();
  public String GetMeshFileName()
    { return GetMeshFileName_2(); }

  private native void SetMeshFileName_3(String id0);
  public void SetMeshFileName(String id0)
    { SetMeshFileName_3(id0); }

  private native void AddModeFileName_4(String id0);
  public void AddModeFileName(String id0)
    { AddModeFileName_4(id0); }

  private native void RemoveAllModeFileNames_5();
  public void RemoveAllModeFileNames()
    { RemoveAllModeFileNames_5(); }

  private native int GetNumberOfModeFileNames_6();
  public int GetNumberOfModeFileNames()
    { return GetNumberOfModeFileNames_6(); }

  private native String GetModeFileName_7(int id0);
  public String GetModeFileName(int id0)
    { return GetModeFileName_7(id0); }

  private native int GetReadInternalVolume_8();
  public int GetReadInternalVolume()
    { return GetReadInternalVolume_8(); }

  private native void SetReadInternalVolume_9(int id0);
  public void SetReadInternalVolume(int id0)
    { SetReadInternalVolume_9(id0); }

  private native void ReadInternalVolumeOn_10();
  public void ReadInternalVolumeOn()
    { ReadInternalVolumeOn_10(); }

  private native void ReadInternalVolumeOff_11();
  public void ReadInternalVolumeOff()
    { ReadInternalVolumeOff_11(); }

  private native int GetReadExternalSurface_12();
  public int GetReadExternalSurface()
    { return GetReadExternalSurface_12(); }

  private native void SetReadExternalSurface_13(int id0);
  public void SetReadExternalSurface(int id0)
    { SetReadExternalSurface_13(id0); }

  private native void ReadExternalSurfaceOn_14();
  public void ReadExternalSurfaceOn()
    { ReadExternalSurfaceOn_14(); }

  private native void ReadExternalSurfaceOff_15();
  public void ReadExternalSurfaceOff()
    { ReadExternalSurfaceOff_15(); }

  private native int GetReadMidpoints_16();
  public int GetReadMidpoints()
    { return GetReadMidpoints_16(); }

  private native void SetReadMidpoints_17(int id0);
  public void SetReadMidpoints(int id0)
    { SetReadMidpoints_17(id0); }

  private native void ReadMidpointsOn_18();
  public void ReadMidpointsOn()
    { ReadMidpointsOn_18(); }

  private native void ReadMidpointsOff_19();
  public void ReadMidpointsOff()
    { ReadMidpointsOff_19(); }

  private native int GetNumberOfVariableArrays_20();
  public int GetNumberOfVariableArrays()
    { return GetNumberOfVariableArrays_20(); }

  private native String GetVariableArrayName_21(int id0);
  public String GetVariableArrayName(int id0)
    { return GetVariableArrayName_21(id0); }

  private native int GetVariableArrayStatus_22(String id0);
  public int GetVariableArrayStatus(String id0)
    { return GetVariableArrayStatus_22(id0); }

  private native void SetVariableArrayStatus_23(String id0,int id1);
  public void SetVariableArrayStatus(String id0,int id1)
    { SetVariableArrayStatus_23(id0,id1); }

  private native void ResetFrequencyScales_24();
  public void ResetFrequencyScales()
    { ResetFrequencyScales_24(); }

  private native void SetFrequencyScale_25(int id0,double id1);
  public void SetFrequencyScale(int id0,double id1)
    { SetFrequencyScale_25(id0,id1); }

  private native void ResetPhaseShifts_26();
  public void ResetPhaseShifts()
    { ResetPhaseShifts_26(); }

  private native void SetPhaseShift_27(int id0,double id1);
  public void SetPhaseShift(int id0,double id1)
    { SetPhaseShift_27(id0,id1); }

  private native long GetFrequencyScales_28();
  public vtkDoubleArray GetFrequencyScales() {
    long temp = GetFrequencyScales_28();

    if (temp == 0) return null;
    return (vtkDoubleArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetPhaseShifts_29();
  public vtkDoubleArray GetPhaseShifts() {
    long temp = GetPhaseShifts_29();

    if (temp == 0) return null;
    return (vtkDoubleArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int CanReadFile_30(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_30(id0); }

  private native long IS_INTERNAL_VOLUME_31();
  public vtkInformationIntegerKey IS_INTERNAL_VOLUME() {
    long temp = IS_INTERNAL_VOLUME_31();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long IS_EXTERNAL_SURFACE_32();
  public vtkInformationIntegerKey IS_EXTERNAL_SURFACE() {
    long temp = IS_EXTERNAL_SURFACE_32();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long POINTS_33();
  public vtkInformationObjectBaseKey POINTS() {
    long temp = POINTS_33();

    if (temp == 0) return null;
    return (vtkInformationObjectBaseKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long POINT_DATA_34();
  public vtkInformationObjectBaseKey POINT_DATA() {
    long temp = POINT_DATA_34();

    if (temp == 0) return null;
    return (vtkInformationObjectBaseKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkSLACReader() { super(); }

  public vtkSLACReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-19-armv6h.pkg.tar.xz: vtk/vtkSLACReader.java <==
// java wrapper for vtkSLACReader object
//

package vtk;
import vtk.*;

public class vtkSLACReader extends vtkMultiBlockDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetMeshFileName_2();
  public String GetMeshFileName()
    { return GetMeshFileName_2(); }

  private native void SetMeshFileName_3(String id0);
  public void SetMeshFileName(String id0)
    { SetMeshFileName_3(id0); }

  private native void AddModeFileName_4(String id0);
  public void AddModeFileName(String id0)
    { AddModeFileName_4(id0); }

  private native void RemoveAllModeFileNames_5();
  public void RemoveAllModeFileNames()
    { RemoveAllModeFileNames_5(); }

  private native int GetNumberOfModeFileNames_6();
  public int GetNumberOfModeFileNames()
    { return GetNumberOfModeFileNames_6(); }

  private native String GetModeFileName_7(int id0);
  public String GetModeFileName(int id0)
    { return GetModeFileName_7(id0); }

  private native int GetReadInternalVolume_8();
  public int GetReadInternalVolume()
    { return GetReadInternalVolume_8(); }

  private native void SetReadInternalVolume_9(int id0);
  public void SetReadInternalVolume(int id0)
    { SetReadInternalVolume_9(id0); }

  private native void ReadInternalVolumeOn_10();
  public void ReadInternalVolumeOn()
    { ReadInternalVolumeOn_10(); }

  private native void ReadInternalVolumeOff_11();
  public void ReadInternalVolumeOff()
    { ReadInternalVolumeOff_11(); }

  private native int GetReadExternalSurface_12();
  public int GetReadExternalSurface()
    { return GetReadExternalSurface_12(); }

  private native void SetReadExternalSurface_13(int id0);
  public void SetReadExternalSurface(int id0)
    { SetReadExternalSurface_13(id0); }

  private native void ReadExternalSurfaceOn_14();
  public void ReadExternalSurfaceOn()
    { ReadExternalSurfaceOn_14(); }

  private native void ReadExternalSurfaceOff_15();
  public void ReadExternalSurfaceOff()
    { ReadExternalSurfaceOff_15(); }

  private native int GetReadMidpoints_16();
  public int GetReadMidpoints()
    { return GetReadMidpoints_16(); }

  private native void SetReadMidpoints_17(int id0);
  public void SetReadMidpoints(int id0)
    { SetReadMidpoints_17(id0); }

  private native void ReadMidpointsOn_18();
  public void ReadMidpointsOn()
    { ReadMidpointsOn_18(); }

  private native void ReadMidpointsOff_19();
  public void ReadMidpointsOff()
    { ReadMidpointsOff_19(); }

  private native int GetNumberOfVariableArrays_20();
  public int GetNumberOfVariableArrays()
    { return GetNumberOfVariableArrays_20(); }

  private native String GetVariableArrayName_21(int id0);
  public String GetVariableArrayName(int id0)
    { return GetVariableArrayName_21(id0); }

  private native int GetVariableArrayStatus_22(String id0);
  public int GetVariableArrayStatus(String id0)
    { return GetVariableArrayStatus_22(id0); }

  private native void SetVariableArrayStatus_23(String id0,int id1);
  public void SetVariableArrayStatus(String id0,int id1)
    { SetVariableArrayStatus_23(id0,id1); }

  private native void ResetFrequencyScales_24();
  public void ResetFrequencyScales()
    { ResetFrequencyScales_24(); }

  private native void SetFrequencyScale_25(int id0,double id1);
  public void SetFrequencyScale(int id0,double id1)
    { SetFrequencyScale_25(id0,id1); }

  private native void ResetPhaseShifts_26();
  public void ResetPhaseShifts()
    { ResetPhaseShifts_26(); }

  private native void SetPhaseShift_27(int id0,double id1);
  public void SetPhaseShift(int id0,double id1)
    { SetPhaseShift_27(id0,id1); }

  private native long GetFrequencyScales_28();
  public vtkDoubleArray GetFrequencyScales() {
    long temp = GetFrequencyScales_28();

    if (temp == 0) return null;
    return (vtkDoubleArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPhaseShifts_29();
  public vtkDoubleArray GetPhaseShifts() {
    long temp = GetPhaseShifts_29();

    if (temp == 0) return null;
    return (vtkDoubleArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int CanReadFile_30(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_30(id0); }

  private native long IS_INTERNAL_VOLUME_31();
  public vtkInformationIntegerKey IS_INTERNAL_VOLUME() {
    long temp = IS_INTERNAL_VOLUME_31();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long IS_EXTERNAL_SURFACE_32();
  public vtkInformationIntegerKey IS_EXTERNAL_SURFACE() {
    long temp = IS_EXTERNAL_SURFACE_32();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long POINTS_33();
  public vtkInformationObjectBaseKey POINTS() {
    long temp = POINTS_33();

    if (temp == 0) return null;
    return (vtkInformationObjectBaseKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long POINT_DATA_34();
  public vtkInformationObjectBaseKey POINT_DATA() {
    long temp = POINT_DATA_34();

    if (temp == 0) return null;
    return (vtkInformationObjectBaseKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkSLACReader() { super(); }

  public vtkSLACReader(long id) { super(id); }
  public native long   VTKInit();

}
